package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````L"4``#0```!4H0```````#0`(``,
M`"@`'0`<``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!,````3````!`````$````!````````````````````0!<`
M`$`7```$`````!````$`````(````"`````@``#P*P``\"L```4`````$```
M`0````!0````4````%```-A#``#80P``!``````0```!````M)T``+2M``"T
MK0``=`(``,P2```&`````!````(```"\G0``O*T``+RM```8`0``&`$```8`
M```$````!````,@!``#(`0``R`$``&P```!L````!`````0```!3Y71D[`$`
M`.P!``#L`0``*````"@````$````!````%#E=&1DC0``9(T``&2-```,`0``
M#`$```0````$````4>5T9```````````````````````````!@```!````!2
MY71DM)T``+2M``"TK0``3`(``$P"```$`````0```"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!0````#````1TY5`-7%%1$UXU.?PPJ7('['#VCM'`SO!```
M`!@````%````1TY5``$``<`$`````0````(``<`$``````````0````0````
M`0```$=.50```````P````0`````````O@```&(`````````````````````
M```````````````P```````````````+`````````#\`````````20```#L`
M`````````````!\`````````&````!D`````````80``````````````````
M````````````6``````````2````````````````````*P````````!#````
M```````````````````````````-`````````&`````W````*0``````````
M``````````\`````````2P```````````````````$X`````````.```````
M```A````7P`````````5````*@````````!2````3P`````````.````````
M```````3````!@```%T```````````````````````````````$```!5````
M``````P``````````````````````````````!0`````````3````$8`````
M````````````````````)0```!H`````````/@````````!:````%@``````
M`````````````#H``````````````%<`````````,P````````!4````````
M`#P```````````````H```!$````````````````````00````D`````````
M`````"8```!3`````````"````!"````!P``````````````,0``````````
M````+```````````````,@```#8````M````4````$@````Y````'@```$4`
M```N``````````````````````````````````````````````!``````P``
M`!L````H````````````````````5@```````````````````%L`````````
M``````````!9`````````$T```!>```````````````C````%P``````````
M````(@```$<````U````+P```!T`````````````````````````````````
M````````````````````````````````````````````````````````"```
M````````````````````````````````````````````````````````````
M````````````````!0``````````````$```````````````````````````
M`````````````````````````````````````````````````````````$H`
M```1````'`````````````````````````````````````0````D````)P``
M````````````````````````````/0``````````````````````````````
M````````````````40`````````````````````````````````````````T
M`````````````````````````%P`````````````````````````````````
M``````````````(````O````2`````@````(`````!`0!"5`!(`H`0`%H(8`
MA(`!```+*`0(.(`208H```@``````````$@``````````````$D`````````
M``````````!+````3`````````!-`````````$X`````````3P``````````
M`````````%``````````40``````````````4P```%0`````````50``````
M````````5P````````!8````60``````````````6@```%P```!=````7@``
M`%\```!@````````````````````80```&L)0]8NQ9NV;\7?'[,!BV]#^M>'
M:W^:?*U+X\!9Z.WLXT?&`0PZEPO#Y3\L(?_D#G^IG)O@IP(*N^.2?-5DU'S/
MWD<M^Z%L8&H:GE"CX/M),V+;[16,)<QGK\QF0T75[(D'<-/9<5@<````````
M`````````````&H"`````````````!(```!I`0`````````````2````9`(`
M````````````$@```$P"`````````````!(```#T`@`````````````2````
MA0$`````````````$@```"H"`````````````!(```"0`@`````````````2
M````@@(`````````````$@```+`!`````````````!(````!````````````
M```@````+0$`````````````$@```'`!`````````````!(```!V````````
M```````2````-0(`````````````$@```-H"`````````````!(```"J`@``
M```````````2````'P$`````````````$@```)\"`````````````!(````0
M```````````````@````X0$`````````````$@```%$"`````````````!(`
M``"B```````````````2````+```````````````(````)L`````````````
M`!(```"I```````````````2````5@(`````````````$@```"8#````````
M`````!(```#]```````````````6````/0$`````````````$@```,,!````
M`````````!(```!8`0`````````````2````\0$`````````````$@```+$`
M`````````````!(```![`@`````````````1````P@``````````````$@``
M`-<``````````````!(```#@`P`````````````2````$`$`````````````
M$@```),!`````````````!(```"*```````````````1````N@(`````````
M````$@```-X``````````````!(```"D`@`````````````2````/@(`````
M````````$@```)H!`````````````!(````C`@`````````````2``````(`
M````````````$@```.@"`````````````!(````5`P`````````````2````
MYP``````````````$@```'<!`````````````!(```":```````````````2
M````[0``````````````$@```#4!`````````````!(``````P``````````
M```2````%P(`````````````$@```,D``````````````!(```"(````````
M```````1````]@``````````````$@```)(``````````````!(```#4`0``
M```````````1````30$`````````````$@```*$!`````````````!(```!^
M`0`````````````2````50``````````````$@```)<"`````````````!(`
M``"[```````````````2````9P``````````````(@```.P!````````````
M`!(```#(`@`````````````2````]0,```"P````````$``9`%D#``#X.@``
M&0```!(`$`#I`P``[C\``&D````2`!``E`,``-$^``!*````$@`0``($``"C
M0```J@```!(`$`!B````\",``+X!```2`!``1@````10```$````$0`2`'<#
M````4```!````!$`$@!J`P``N3P``!H````2`!``]P,```"P````````(``9
M``T$``"O.0``/P```!(`$`!5!```$3L``*@!```2`!``S@,``!L_```L````
M$@`0`*(#``!(.@``L````!(`$``J!```@,`````````0`!H`?@,``*](``#@
M`@``$@`0`"\$``!V0@``.08``!(`$`!#!```1S\``*<````2`!``Q`,``$U!
M```I`0``$@`0`&P$``!Z/0``5P$``!(`$`#[`P``L"4``"P````2`!``(00`
M`%=```!,````$@`0`+@#``#3/```IP```!(`$``\!```*+`````````0`!D`
M8@0``"2P```$````$0`9`!4$```HL````````!``&@``7U]G;6]N7W-T87)T
M7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)4
M34-L;VYE5&%B;&4`7TE/7W-T9&EN7W5S960`7U]L:6)C7W-T87)T7VUA:6X`
M7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]A=&9O<FL`7U]E;G9I<F]N`'-T
M<FYC;7``;'-T870V-`!A8V-E<W,`;W!E;F1I<@!R96%D9&ER-C0`<W1R8VUP
M`'-T<FQE;@!?7W-P<FEN=&9?8VAK`'5N;&EN:P!C;&]S961I<@!R;61I<@!R
M96%D;&EN:P!M96UC:'(`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?<W9?<V5T
M<'9N`%!E<FQ?<W9?<V5T<'8`<F5A;&QO8P!M96UM;W9E`&)O;W1?1'EN84QO
M861E<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA9W,`9V5T<&ED`'-T<F-H
M<@!S=')T;VL`<W1R9'5P`%]?<W1R;F-P>5]C:&L`9V5T=6ED`'-T<G-T<@!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?
M;&]C:P!03%]D;U]U;F1U;7``<&5R;%]A;&QO8P!E>&ET`'!E<FQ?8V]N<W1R
M=6-T`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``4&5R;%]S869E<WES;6%L;&]C
M`'!E<FQ?<&%R<V4`<&5R;%]R=6X`<&5R;%]D97-T<G5C=`!P97)L7V9R964`
M4&5R;%]S>7-?=&5R;0!M:V1I<@!?7V5R<FYO7VQO8V%T:6]N`'-T9&5R<@!?
M7V9P<FEN=&9?8VAK`&]P96XV-`!L<V5E:S8T`')E860`8VQO<V4`4&5R;%]G
M=E]F971C:'!V`%!E<FQ?879?9F5T8V@`4&5R;%]S=E\R<'9?9FQA9W,`4&5R
M;%]A=E]S:&EF=`!097)L7VUG7W-E=`!097)L7V=E=%]S=@!097)L7V-R;V%K
M7VYO8V]N=&5X=`!?7W-T86-K7V-H:U]F86EL`%]?7W1L<U]G971?861D<@!L
M:6)P97)L+G-O`&QI8F,N<V\N-@!L9"UL:6YU>"YS;RXR`'!A<E]C=7)R96YT
M7V5X96,`<&%R7V)A<V5N86UE`%]F<%]H=P!84U]);G1E<FYA;'-?4$%27T)/
M3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I
M<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B
M<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A
M<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN
M:71?96YV`$=,24)#7S(N,P!'3$E"0U\R+C$N,P!'3$E"0U\R+C,T`$=,24)#
M7S(N-`!'3$E"0U\R+C(`1TQ)0D-?,BXS,P!'3$E"0U\R+C,N,@!'3$E"0U\R
M+C$`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXP`"]U<W(O;&EB+W!E<FPU+V-O<F5?
M<&5R;"]#3U)%``````(``@`"``$``0`#``$`!``#``$``0`"``(`!0`!``$`
M`0`!``(``0`!``(``@`!``8``@`!``<``0`!``$``0`!``@``@`"``(``@`!
M``(``@`!``(``@`!``(``@`!``$`"0`"``(`!@`"``(``0`!``,``@`"``(`
M`0`!``$``@`*``0``@`+``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!`$L#```0````(````!-I
M:0T```<`>00````````!``D`00,``!``````````<Q]I"0``"P"#!```$```
M`+21E@8```H`CP0``!`````4:6D-```)`)H$```0````$FEI#0``"`"D!```
M$````+.1E@8```8`K@0``!````!R&6D)```%`+D$```0````$6EI#0``!`#%
M!```$````'09:0D```,`SP0``!`````0:6D-```"`-L$````````M*T```@`
M``"XK0``"````-2O```(````_*\```@````$L```"`````BP```(````#+``
M``@````0L```"````!2P```(````&+````@````DL```"````,RO```&"@``
MT*\```8+``#8KP``!A0``-RO```&&```X*\``"4=``#DKP``!AX``.BO```&
M'P``[*\```8C``#PKP``!BD``/2O```&/@``^*\```9%``#@K@``!P$``.2N
M```'`@``Z*X```<#``#LK@``!P0``/"N```'!0``]*X```<&``#XK@``!P<`
M`/RN```'"````*\```<)```$KP``!PP```BO```'#0``#*\```<.```0KP``
M!P\``!2O```'$```&*\```<1```<KP``!Q(``""O```'$P``)*\```<5```H
MKP``!Q8``"RO```'%P``,*\```<9```TKP``!QH``#BO```'&P``/*\```<<
M``!`KP``!R```$2O```'(0``2*\```<B``!,KP``!R0``%"O```')0``5*\`
M``<F``!8KP``!R<``%RO```'*```8*\```<J``!DKP``!RL``&BO```'+```
M;*\```<M``!PKP``!RX``'2O```'+P``>*\```<P``!\KP``!S$``("O```'
M,@``A*\```<S``"(KP``!S0``(RO```'-0``D*\```<V``"4KP``!S<``)BO
M```'.```G*\```<Y``"@KP``!SH``*2O```'/```J*\```<]``"LKP``!S\`
M`+"O```'0```M*\```=!``"XKP``!T(``+RO```'0P``P*\```=$``#$KP``
M!T8``,BO```'1P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!3@^P(Z-<%``"!P\N.``"+@_P```"%P'0"_]"#Q`A;P_^S!````/^C"```
M``````#_HPP```!H`````.G@_____Z,0````:`@```#IT/____^C%````&@0
M````Z<#_____HQ@```!H&````.FP_____Z,<````:"````#IH/____^C(```
M`&@H````Z9#_____HR0```!H,````.F`_____Z,H````:#@```#I</____^C
M+````&A`````Z6#_____HS````!H2````.E0_____Z,T````:%````#I0/__
M__^C.````&A8````Z3#_____HSP```!H8````.D@_____Z-`````:&@```#I
M$/____^C1````&AP````Z0#_____HT@```!H>````.GP_O___Z-,````:(``
M``#IX/[___^C4````&B(````Z=#^____HU0```!HD````.G`_O___Z-8````
M:)@```#IL/[___^C7````&B@````Z:#^____HV````!HJ````.F0_O___Z-D
M````:+````#I@/[___^C:````&BX````Z7#^____HVP```!HP````.E@_O__
M_Z-P````:,@```#I4/[___^C=````&C0````Z4#^____HW@```!HV````.DP
M_O___Z-\````:.````#I(/[___^C@````&CH````Z1#^____HX0```!H\```
M`.D`_O___Z.(````:/@```#I\/W___^CC````&@``0``Z>#]____HY````!H
M"`$``.G0_?___Z.4````:!`!``#IP/W___^CF````&@8`0``Z;#]____HYP`
M``!H(`$``.F@_?___Z.@````:"@!``#ID/W___^CI````&@P`0``Z8#]____
MHZ@```!H.`$``.EP_?___Z.L````:$`!``#I8/W___^CL````&A(`0``Z5#]
M____H[0```!H4`$``.E`_?___Z.X````:%@!``#I,/W___^CO````&A@`0``
MZ2#]____H\````!H:`$``.D0_?___Z/$````:'`!``#I`/W___^CR````&AX
M`0``Z?#\____H\P```!H@`$``.G@_/___Z/0````:(@!``#IT/S___^CU```
M`&B0`0``Z<#\____H]@```!HF`$``.FP_/___Z/<````:*`!``#IH/S___^C
MX````&BH`0``Z9#\____H^0```!HL`$``.F`_/___Z/H````:+@!``#I</S_
M__^C[````&C``0``Z6#\____H_````!HR`$``.E0_/___Z/T````:-`!``#I
M0/S___^C)`$``&:0``````````"-3"0$@^3P_W'\C4$(58GE5U:)SE/HU@$`
M`('#RHH``%&-9"3T4(U!!%!1Z%#___^#Q`R+@_@```!04/^S%`$``.AE)P``
MBX,@`0``@\00@#@`=3KH]_S__X7`B8.0`0``=0J#[`QJ`>AC____@^P,4.A:
M_?__9:$`````*X,,`0``BP"#Q!#&@$,&````9:$`````*X,,`0``BP"`B)H"
M```#BP:#P`4]____/W8%Z.S]___!X`*#[`Q0Z'#^__^+?@2)@YP!``#'@Y@!
M```$````@\00N0$```"+%XD0C9-OHO__B5`$C9-0`0``BQ*)4`B-DW*B__^)
M4`R+%CG*?@J+-(^)=(@,0>OR@^P,,<F)3)`,@\(#:@!0C8,:B___4E#_LY`!
M``#H<OO__X/$((7`B<9U$X/L#/^SD`$``.B[^___B<:#Q!"#[`S_LY`!``#H
M&/W__XV#U*'__^B`#P``@\00A<!U,(.[E`$```!U$8V#B:'__^AE#P``B8.4
M`0``BX.4`0``A<!T#(/L#%#H9QH``(/$$(/L#/^SD`$``.C(^O__@\00Z/#[
M__^-9?")\%E;7E]=C6'\PV:0,>U>B>&#Y/!05%+H&````('#%(D``&H`:@!1
M5O^S*`$``.BY_?__](L<),-FD&:0BQPDP^B_````!>N(``"-B%0!``"-D%0!
M```YRG09BX`$`0``A<!T#U6)Y8UD).Q1_]"#Q!#)P\/HEP```('!MX@``%6-
M@50!``")Y593C9E4`0``*=C!^`*^`@```)GW_H7`=!.+D0@!``"%TG0)45%0
M4__2@\00C67X6UY=PU6)Y5/H>/___X'#;(@``%"`NVP!````=2:#NR0!````
M=!&#[`S_LS`!``#H4?W__X/$$.A-____QH-L`0```8M=_,G#Z7#___^0D)"0
MD)"0D(L$),.0D)"0D)"0D(L,),-5,=*)Y5=64XVD)(3^__^)A93^__]EH10`
M``")1>0QP(N%E/[__XM,D!R-A:3^__\/R8D,D$*#^A!UY8U-I(M0-(/`!#-0
M'#-0!#-0_-'"B5`\.<AUZ(N%E/[__XL`B86,_O__BX64_O__BYV,_O__P<L"
MBT`$B86$_O__BX64_O__B[6$_O__P<X"BT`(B860_O__BX64_O__BXV0_O__
M,?&+0`R)A8C^__^+A93^__^+0!")A7C^__^+A:3^__^+O7C^__^-E`>9>8):
MBX6,_O__P<`%B[V(_O__`<*+A9#^__\Q^(N]A/[__R'XB[V(_O__,?@!PHN%
MC/[__R'!BX60_O__,<&+A:C^__^-A`>9>8):`<B)T8N]K/[__\'!!0'(B?&)
MA8#^__^+A9#^__\QV2'1P<H",?&-O#B9>8):`?F+O8#^__^+A8#^___!QP4!
MSXG9,=$AP8N%L/[__S'9C;0&F7F"6@'QB?[!Q@6-!#&)A7S^__^+A8#^__^+
MM;3^___!R`*)T3'!(?DQT8V<,YEY@EH!V8N=?/[__\'#!<'/`HTT&8G!BYU\
M_O__,?DAV8N=N/[__S'!C90:F7F"6@'*B?&+G;S^___!P04!RHGYB96`_O__
MBY5\_O__P<H"C808F7F"6C'1(?'!S@(Q^0'(BXV`_O__P<$%C1P(B="+C8#^
M__\Q\"'(BXW`_O__,="-C`^9>8):`<B)V8N]Q/[__\'!!0'(B?&)A7S^__^+
MA8#^___!R`*-E#J9>8):,<$AV<'+`C'Q`<J+C7S^___!P06-/`J)PHN-?/[_
M_S':(<J+C<C^__\QPHV,#IEY@EH!RHGYP<$%C30*BY5\_O__P<H"B;6`_O__
MB=F+M<S^__\QT2'YP<\",=F-A#"9>8):`<B+C8#^___!P06--`B)T#'XBXV`
M_O__(<B+C=#^__\QT(V,"YEY@EH!R(GQBYW4_O__P<$%`<B)^8F%?/[__XN%
M@/[__\'(`HV4&IEY@EHQP2'QP<X",?D!RHN-?/[__\'!!8T<"HG",?*+C7S^
M__\ARHN-V/[__S'"C8P/F7F"6@'*B=G!P06-/`J)O8#^__^+E7S^__^+O=S^
M___!R@*)\3'1(=DQ\8V$.)EY@EK!RP(!R(N-@/[__\'!!8T\"(G0,=B+C8#^
M__\AR(N-X/[__S'0C8P.F7F"6@'(B?F+M>3^___!P04!R(G9B85\_O__BX6`
M_O__P<@"C90RF7F"6C'!(?G!SP(QV0'*BXU\_O__P<$%C30*B<(Q^HN-?/[_
M_R'*BXWH_O__,<*-C`N9>8):`<J)\<'!!8T<"HN5?/[__\'*`HGY,=$A\<'.
M`C'YB8V`_O__BXWL_O__C80(F7F"6HN-@/[__P'(B=G!P04!R(G1,?$AV3'1
MB8V`_O__BXWP_O__C;P/F7F"6HN-@/[__P'YB<?!QP4!^8N]]/[__\'+`HV\
M.J'KV6Z)\C':,<+!R`(!^HG/P<<%`?J+O?C^__^-O#ZAZ]ENB=XQQC'.`?Z)
MU\''!0'^B<_!SP*+C?S^__^-G`NAZ]ENB<$Q^3'1`=F)\\'#!0'9B=/!RP*+
ME0#___^-E!"AZ]ENB?@QV#'PP<X"`=")RL'"!0'0BY4$____C;P7H>O9;HG:
M,?(QRL')`@'ZB<?!QP4!^HN]"/___XV\.Z'KV6Z)\S'+,</!R`(!^XG7P<<%
M`?N)QXN%#/___XVT!J'KV6Z)R#'X,=`!\(G>P<8%`?")UL'.`HN5$/___XV4
M$:'KV6Z)^3'Q,=G!RP(!T8G"P<(%`=&+E13___^-O!>AZ]ENB?(QVC'"P<@"
M`?J)S\''!0'ZB<>+A1C___^-A`:AZ]ENB=XQ_C'.P<D"`<:)T,'`!0'&BX4<
M____C9P#H>O9;HGX,<@QT`'8B?/!PP4!V(G3P<L"BY4@____C907H>O9;HG/
M,=\Q]\'.`@'7B<+!P@4!UXN5)/___XV,$:'KV6Z)VC'R,<+!R`(!RHGYP<$%
M`<J)P8N%*/___XV$`Z'KV6Z)\S'+,?O!SP(!PXG0P<`%`<.+A2S___^-M`:A
MZ]ENB<@Q^#'0P<H"`?")WL'&!0'PB[4P____C8PQH>O9;HG^,=8QW@'.B<'!
MP04!SHN--/___\'+`HV,#Z'KV6Z)US'?,<?!R`(!SXGQP<$%`<^+C3C___^-
ME`JAZ]ENB=DQP3'QP<X"`=&)^HFU@/[__\'"!0'1BY4\____C9P3H>O9;HGR
M,<(Q^L'/`@':B<O!PP4!VHN=0/___XV<&*'KV6Z)\#'XB?XQR,')`@'8B=,)
MSL'#!2'6`=B)^R'+"?.+M43___^)G7S^__^+G8#^__^-M#/<O!N/BYU\_O__
M`?.)QL'&!0'>B<O!R@*)M8#^__^)SB'3"=8AQL'(`@GSB[5(____C;0WW+P;
MCP'SB[6`_O__P<8%C3PSB=:+G8#^__\)QB'>B=,APPGSB[5,____C8PQW+P;
MCP'9B?O!PP6--!F+C8#^__^)M7S^__^)QL')`HG#"<XARR'^P<\""?.+M5#_
M__^-E#+<O!N/`=J+G7S^__^)SL'#!0G^`=J)RXF5@/[__XGZB[U\_O__(=,A
M_@GSB[54____C80PW+P;CP'8BYV`_O__B=;!PP6-/!B+A7S^___!R`*+G8#^
M__\)QB'>B=,APPGSB[58____C8PQW+P;CP'9B?O!PP6--!F+C8#^___!R0*)
MM7S^__^)QHG#"<XARR'^P<\""?.+M5S___^-E#+<O!N/`=J+G7S^__^)SL'#
M!0G^`=J)RXF5@/[__XGZB[U\_O__(=,A_@GSB[5@____C80PW+P;CP'8BYV`
M_O__B=;!PP6-/!B+A7S^___!R`*+G8#^__\)QB'>B=,APPGSB[5D____C8PQ
MW+P;CP'9B?O!PP6--!F+C8#^__^)M7S^__^)QL')`HG#"<XARR'^"?.+M6C_
M__^-E#+<O!N/`=J+G7S^__^)SL'#!<'/`@':B96`_O__"?Z)^HG+B[U\_O__
M(=,A_@GSB[5L____C80PW+P;CP'8BYV`_O__B=;!PP6-/!B+A7S^___!R`*+
MG8#^__\)QB'>B=,APPGSB[5P____C8PQW+P;CP'9B?O!PP6--!F+C8#^__^)
MM7S^__^)QL')`HG#"<XARR'^P<\""?.+M73___^-E#+<O!N/`=J+G7S^__^)
MSL'#!0G^`=J)RXF5@/[__XGZB[U\_O__(=,A_@GSB[5X____C80PW+P;CP'8
MBYV`_O__B=;!PP6-/!B+A7S^___!R`*+G8#^__\)QB'>B=,APPGSB[5\____
MC8PQW+P;CP'9B?O!PP6--!F+C8#^___!R0*)M7S^__^)QHG#"<XARR'^P<\"
M"?.+=8"-E#+<O!N/`=J+G7S^__^)SL'#!0G^`=J)RXF5@/[__XGZB[U\_O__
M(=,A_@GSBW6$C80PW+P;CP'8BYV`_O__B=;!PP6-/!B+A7S^___!R`*+G8#^
M__\)QB'>B=,APPGSBW6(C8PQW+P;CP'9B?O!PP6--!F+C8#^___!R0*)M7S^
M__^)QHG#"<XARR'^"?.+=8S!SP*-E#+<O!N/`=J+G7S^__^+M7S^___!PP4!
MVHG[B<\)WR'WB<XAW@G^BWV0C80XW+P;CXM]E`'PB=;!Q@4!\(NU?/[__\'.
M`HV,.=;!8LJ)WS'W,=?!R@(!SXG!P<$%`<^+39B-G`O6P6+*B?$QT3'!P<@"
M`=F)^\'#!0'9B<.+19R-A`;6P6+*B=8QWC'^P<\"`<:)R,'`!0'&BT6@C90"
MUL%BRHG8,?@QR,')`@'0B?+!P@4!T(M5I(V4$];!8LJ)^S'+,?/!S@(!TXG"
MP<(%`=.+5:B-O!?6P6+*B<HQ\C'"P<@"`?J)W\''!0'ZB<>+1:R-A`'6P6+*
MB?$Q^3'9P<L"`<&)T,'`!0'!BT6PC;0&UL%BRHGX,=@QT,'*`@'PB<[!Q@4!
M\(G6BU6TC907UL%BRHG?,?<QSP'7B<+!P@7!R0(!UXM5N(V<$];!8LJ)\C'*
M,<+!R`(!VHG[P<,%`=J)PXM%O(V$!M;!8LJ)SC'>,?[!SP(!QHG0P<`%`<:+
M1<"-C`'6P6+*B=@Q^#'0P<H"`<B)\<'!!0'(B=&+5<2-E!/6P6+*B?LQRS'S
MP<X"`=.)PL'"!0'3BU7(C;P7UL%BRHG*,?(QP@'ZB=_!QP4!^L'(`HG'BT7,
MC80!UL%BRHGQ,?DQV<'+`@'!B=#!P`4!P8M%T(VT!M;!8LJ)^#'8,=`!\(G.
MP<8%`?")UL'.`HM5U(V4%];!8LJ)WS'W,<_!R0(!UXG"P<(%`=>+5=B-G!/6
MP6+*B?(QRC'"P<@"`=J)^\'#!0':BUW<C;0>UL%BRHG+,<,Q^\'/`@'SB=;!
MQ@4!WHFU@/[__XMUX(N=C/[__XVT,];!8LH!SHG!,?DQT<'*`@'QB[6`_O__
MP<8%`?&+M93^__^)#HNUA/[__XN-@/[__P'QB[64_O__B4X$B[60_O__`?*+
MM93^__^)5@B+E8C^__\!^HN]>/[__P'XB58,B480BT7D92L%%````'0%Z(T7
M``"-I"1\`0``6UY?7<-5B>575C'V4^B0\?__@<.$>@``C60DY(7`B57@=&B)
MP8N#'`$``#'VB<^+$(72=%:*!X3`=`<\/70#1^OS*<^)5>2+1>2+,(7V=#N)
M5=A05U&)3=Q6Z+/N__^#Q!"%P(M-W(M5V'49@#P^/743BUW@BT7D*="-=#X!
MP?@"B0/K!H-%Y`3KO(UE](GP6UY?7<-5B>6-9"3H98L5%````(E5]#'2C57P
MZ%7___^+5?1E*Q44````=`7HQ18``,G#58GE5NB%%@``@<;*>0``4XG#C60D
M\&6A%````(E%]#'`C57PB=CH%____X7`=!R+AAP!``"+5?"+`(T$D(M0!(72
MB1!TVX/`!.ORBT7T92L%%````'0%Z&<6``"-9"006UY=PU6)Y5:)QE/H;_#_
M_X'#8WD``(UD)(AEH10```")1?0QP(U%E%!6Z%#M__^#Q!"%P'4PBU6D@>(`
M\```@?H`0```=`B!^@"@``!U&5!0:@)6Z*;K__^#Q!"%P`^4P`^VP.L",<"+
M5?1E*Q44````=`7HZA4``(UE^%M>7<-5B>575HG&4^CR[___@</F>```C:0D
M=/___V6A%````(E%Y#'`A?8/A!L!``"`/@`/A!(!``"#[`Q6Z&#K__^#Q!"%
MP(F%</___P^$^````(/L#/^U</___^B1Z___@\00A<`/A,8```"#P!.)A73_
M__]04(V#-:'__U#_M73____H2>W__X/$$(7`=,-04(V#-*'__U#_M73____H
M+NW__X/$$(7`=*B#[`Q6Z$[K__]:B<?_M73____H0.O__XU$!P*)!"3HU.O_
M_UF)QUB-@S>A____M73___]64&K_:@%7Z&CL__^#Q!B-18105^B;ZO__@\00
M0'08BT64)0#P```]`$```'4)B?CH\/[__^L,@^P,5^CTZO__@\00@^P,5^A(
MZO__@\00Z2'___^#[`S_M7#____H(NO__XDT).B:Z___@\00BT7D92L%%```
M`'0%Z(H4``"-9?1;7E]=PU6)Y5=6B<:-O>3O__]3Z(ON__^!PW]W``"-I"30
M[___B974[___9:$4````B47D,<!H_P\``(V#/:'__U=0Z&OK__^#Q!"%P'Y*
M@+P%X^___P"-4/]U!H72=#GK`HG"45*)E=#O__]J+U?HC^O__X/$$(7`=!Z+
ME=#O__]25U9EH0`````K@PP!``#_,.@\ZO__ZQM0_[74[___5F6A`````"N#
M#`$``/\PZ"_I__^#Q!"+1>1E*P44````=`7HOQ,``(UE]%M>7UW#58GE5U:)
MUE/HQNW__X'#NG8``(UD)-2)1=1EH10```")1>0QP(`Z/74!1H/L#%;HG^G_
M_XE%S(/$$(U5X(M%U.CQ^___A<")QW0I@^P,4.A_Z?__BTW,@\00.<@/@K$`
M```QP(H4!H@4!T"$TG7UZ14!``"+@QP!``"+"#'`B470BT70@SR!`'0%_T70
MZ_*#NXP!````C3R%"````'0=4%!74>@+Z/__BY,<`0``@\00A<")`G5(Z<T`
M``"#[`R)3<C'@XP!```!````5^BAZ?__@\00A<")P@^$J@```%&-1_A0BTW(
M45*)5<CH`NK__XN#'`$``(M5R(/$$(D0BX,<`0``,=*+`(E4./R+1=")1>"+
M1=2*$(32=`B`^CUT`T#K\HN3'`$``(M]X(/L#(E5R(L*C0RYB4W0BTW4*<B+
M3<R-1`$"4.@FZ?__BTW0@\00A<")`70PBU7(BP*+!+C_1=2)P8M]U$"*5_^(
M4/^`^CUT!(32=>C&`3TQTHH,%H@,$$*$R77UBT7D92L%%````'0%Z!T2``"-
M9?1;7E]=PU6)Y5/H*.S__X'#''4``%"-@X3>__]0C8-,H?___[,0`0``4&6A
M`````"N##`$``/\PZ'KI__^#Q!"+7?S)PU6)Y5/HZ>O__X'#W70``(UD)/!E
MH0`````K@PP!``#_,.B;____6(V#]Z/__UIJ`%!0C8-HH?___[,``0``4&6A
M`````"N##`$``/\PZ'#G__^#Q""+7?S)PU6)Y5=6C;WC[___C;7BW___4^B!
MZ___@<-U=```C:0DU-___V6A%````(E%Y#'`Z,3E__]24HV32*'__U)0C8-]
MH?__4&@!$```:@%7Z);H__^#Q!QH`!```%97Z$?H__^#Q!"%P'@AB<*#[`R-
M0`&)E=3?__]0Z+SG__^#Q!"%P(N5U-___W4$,<#K"HG'B='SI,8$$`"+5>1E
M*Q44````=`7HU!```(UE]%M>7UW#58GE4^C?ZO__@</3<P``4.@[____6EM=
MPU6)Y5=64^C$ZO__@<.X<P``C:0D=.___XMU"&6A%````(E%Y#'`C8.)H?__
MBWT,Z([Y__^)A73O__]04&HO5NA[Y?__@\00A<!T$HGRC8.2H?__Z*3\___I
M,`$``(/L#%;H:>;__UI9B85P[___C8.?H?__4%?H1.?__X/$$(7`B<=TQX`_
M`'4&C;LUH?__@[UT[___`'0[4%!7_[5T[___Z/GG__^#Q!"%P'4F5XV#GZ'_
M_U=0:@#H`N?__X/$$(7`B<=TA8`X`'7-C;LUH?__Z\6#[`Q7Z//E__^#Q!"`
M?`?_+W4'2,8$!P#K\HN-<.___XU$"`$]_P\```^/2?___U&-@Z&A__]64(V#
MEJ+__U>-O>3O__]0:``0``!J`5?H^>;__X/$&(V%A.___U!7Z"GE__^#Q!"%
MP'5`BX64[___)0#P```]`(```'4N4E)J`5?H]N3__X/$$(7`=1V)^HV#DJ'_
M_^B/^___@^P,5^CYYO__B<:#Q!#K$%!0C8.?H?__4&H`Z>G^__^+1>1E*P44
M````=`7H%0\``(UE](GP6UY?7<-5B>6+10B)PHH(A,ET"$"`^2]U].OPB=!=
MPU6)Y593Z`/I__^!P_=Q``"+=0B%]G0T@#X`="^#[`Q6Z.CD__^-1`;_@\00
M.<9S$H`X+W4)2.OT@#@O=#)(.<9R]CG&=2F`/B]U"X/L#(V#-:'__^L)@^P,
MC8.AH?__4.A(YO__@\00ZS:`."]U!4@YQG+V*?")PHU(`C'`@?D`$```=QMH
M`!```(U"`5!6C;.L`0``5N@2X___@\00B?"-9?A;7EW#5;DB````B>575HU]
MPE/H4^C__X'#1W$``(UD)+2-LV#>__]EH10```")1>0QP(V#HZ'___.DZ$SW
M__^-@ZRA__^-LXFA___H._?__XV#M*'__XV[ZJ'__^@J]___C8.]H?__Z!_W
M__^-@\2A__^)1;#H$??__XV#U*'__^@&]___B?#H__;__XV#X*'__XE%M.CQ
M]O__B?CHZO;__XV#]*'__^C?]O__C8.2H?__Z-3V__^-@_ZA___HF_;__X7`
M=`F)PHGXZ,CY__^-@P^B___H@_;__X7`B<)T"XV#(:+__^BL^?__C8,LHO__
MZ&?V__^)PHGPA=)U,8V#/*+__^A4]O__A<")PG4=4(V#3:+__VH*4(U%TU#H
MN.3__X/$$(7`=0N-5=V+1;3H8_G__XM%L(V36*+__^A5^?__BT7D92L%%```
M`'0%Z/L,``"-9?1;7E]=PU6)Y5/H!N?__X'#^F\``%&#NTP!``#_=2>-@^"A
M___HWO7__S'2A<!T$(H`/#`/E<$QTH3`#Y7"(<J)DTP!``"+@TP!``!:6UW#
M58GE4^B\YO__@<.P;P``4.CPXO__@^P,4.C'XO__@\00A<!T`HL`BUW\R<-5
MB>575E/HCN;__X'#@F\``(UD).2-@UJB__^)1>2+=0CH9O7__X7`=`>`.`")
MQW4$B?+K6U!05E?HZ^+__X/$$(7`=5J#[`Q6Z$OB__^)1>")/"3H0.+__XM-
MX(U$`0*)!"3HT>+__X/$#(G"5XV#GZ'__U"-@Y:B__]64&K_:@%2B57@Z%_C
M__^#Q""+5>"+1>2-9?1;7E]=Z2?X__^-9?1;7E]=PU6)Y5=64^CGY?__@</;
M;@``C60DZ(M]"%?HQ_S__XD$).BE_/__@\00B<;HL_[__X7`="V%_W0I@#\`
M="104(V#:J+__U!6Z#;B__^#Q!`YQG4.C67TB?A;7E]=Z9+U__^-9?1;7E]=
MPU6)Y5/H@.7__X'#=&X``(UD)/!J8.@/XO__,=+'``$C16?'0`2)J\WOQT`(
M_MRZF,=`#'94,A#'0!#PX=+#B5`4B5`8B5!<BUW\R<-5B>575E.-9"3DBUT(
MBT40P>`#`T,4<P/_0QB)0Q2+11#!Z!V+4UP!0QB%THU#'(E%Y'0WN$`````I
MT#M%$'X#BT40BTWDBW4,`<J)P8G7\Z2+4UP!PH/Z0(E37'5#*440B=B)=0SH
MLN7__XM5$(MU#`-U$"G6@_H_?AR+?>2Y$````/.E@^I`B=B)5>#HB^7__XM5
MX.O7BWWDB='SI(E37(UD)!Q;7E]=PU7H5>7__P6!;0``B>575E.-9"34BUT,
MB47@BW4(BT,4B<(/RL'H`XE5W(/@/XM3&`_*B578C5,<B57DC7@!QD0#'("#
M_SB-%#I^)KE`````,<`I^8G7\ZJ)V(E-U.@1Y?__N0X```"+?>2+1=3SJ^L-
MN3@````QP"GYB=?SJHM%V(E#5(M%W(E#6(G8Z.+D__^+`X/L#,'H&(@&BP/!
MZ!"(1@&+`XAF`HL#B$8##[9#!XA&!`^W0P:(1@6+0P2(9@:+0P2(1@</MD,+
MB$8(#[=#"HA&"8M#"(AF"HM#"(A&"P^V0P^(1@P/MT,.B$8-BT,,B&8.BT,,
MB$8/#[9#$XA&$`^W0Q*(1A&+0Q"(9A*+0Q"(1A-3BUW@Z.7>__^#Q!"-9?1;
M7E]=PU6Y!@```(GE5U8Q]HV]C'___U/H4N/__X'#1FP``(VD)`1___^+10B)
MA?Q^__]EH10```")1>0QP(FUB'___XVS-`$``/.EC8-\HO__,?^)A8!___^-
M@S6A__^)A81___^-@X&B__^)A71___^-@X:B__^)A7A___^-@XFA__^)O7Q_
M___HT_'__X7`=".`.`")QG0<@^P,4.@S_/__B30DZ&3@__^)A01____I9@4`
M`.CO^___A<")QXVU='___W4QBP:%P'0EZ)#Q__^%P'07@#@`=!*#[`Q0Z"O@
M__^#Q!"%P(G'=0N#Q@3KU8V[=:+__X/L#%?H;M[__XU$``&)!"3H`M___XF%
M!'___X/$$(G&#[8'A,!T'H/L#$=0C8./HO__4&K_:@%6@\8"Z(??__^#Q"#K
MVXV]C'___XLWA?9T*8GPZ!+Q__^%P(G&="2`.`!T'^B4\?__A<!T%H/L#%;H
MHM___XG&@\00C;V`?___ZSB#QP3KQ(L/A<ET,X`Y`'0PB<B)C0!____H7?'_
M_X7`C7\$BXT`?___=-N#[`Q1Z&+?__^)QH/$$(7V=,GK`C'V@^P,5NBLW?__
M68G'_[4$?___Z)[=__^-O`<$!```B3PDZ"_>__^)A0!___^-@VJB____M01_
M__]0C8.AH?__4(V#E*+__U90:O]J`?^U`'___^BNWO__@\0H:,`!``#_M0!_
M___HN]O__X/$$$!U)>B0V___BP"#^!%T&5)24/^U`'___XN%_'[___\PC8.=
MHO__ZTI04(V%%'___U#_M0!____H#-[__X/$$(7`B87X?O__=1*+A21___\E
M`/```#T`0```=#>#[`S_M0!___^+A?Q^____,(V#V*+__U"+@Q@!``!J`?\P
MZ);;__\QP(/$((F%!'___^EF`P``B[4L?___Z.O<__\YQG6ZBX4D?___)?\!
M```]P`$``'6H@^P,5^@LW?__B84$?___C8-EHO__Z&[O__^#Q!"%P'4*BX7\
M?O__BS#K(H/L#%#H`=[__UY?4(N%_'[___\PZ(+U__^#Q!"%P(G&=-2#[`Q6
MZ#_<__^#Q!"#^`.)QW9@48V#*Z/__U%0C40^_%#H\MW__X/$$(7`=4:#_P1T
M!X!\/OLO=3J+A?Q^__^+>`2%_W0M@^P,5^CYV___@\00@_@#=AQ2C40'_%*-
MDS"C__]24.BNW?__@\00A<!U`HG^Z,'X__^%P(F%_'[__P^%F@$``%=7:@!6
MZ'C:__^#Q!"%P(G&#X2#`0``:@*-O>1___]J_VKN4.A9W?__@\0,:@975NC=
MVO__@\00@+WD?___`'5X@+WE?___0W5O@+WF?___075F@+WG?___0W5=@+WH
M?___2'54@+WI?___175+:@)J_VK&5N@(W?__@\0,:BE75NB,VO__C8/WH___
M4(V#H:'__U=0C8,UH____[4`?___4&K_:@'_M01____H8=S__X/$,.F+`0``
M:@!J`&H`5NB]W/__Z&_Y__^)QX/$$(V5Y'___U!H`(```%*)E?A^__]6Z"K:
M__^#Q!"%P(N5^'[__WX+45!25^B'^?__Z\R#[`Q6Z"G;__]9C870?___7E=0
MZ!?Z__^#Q!"+A?Q^__^#[`R-M:=___\/MH0%T'___U"-@X^B__]0:O]J`8N%
M_'[__P'``?!0Z,3;____A?Q^__^#Q""#O?Q^__\4=;N-@_>C___&A<]___\`
M4(V#H:'__U90C8,UH____[4`?___4&K_:@'_M01____H@-O__X/$(.FJ````
MC9-8HO__C8/@H?__Z$3P___H<MC__XV3]Z/__U)0C8.AH?__4(V#1*/___^U
M`'___U!J_VH!_[4$?___Z#?;__^#Q"!24FC``0``_[4$?___Z$+8__^#Q!!`
M=4[H%]C__X,X$75$_X7X?O__Z!?8__^#[`R-D_>C__]2_[7X?O__4(V#H:'_
M_U"-@U*C____M0!___]0:O]J`?^U!'___^C3VO__@\0PZYJ#[`S_M0!____H
MX-C__XV#B:'__XN5!'___^B,[___6/^U!'___^BZ]O__@\00BT7D92L%%```
M`'0%Z",#``"+A01___^-9?1;7E]=PU6)Y5=64^@FW?__@<,:9@``C60DY&6A
M`````"N##`$``(L`BE!DB%!EC8/$H?__Z/#K__^%P'0+@#@Q=0:`>`$`=`7H
M@_3__VH+C8-OH___:@%09:$`````*X,,`0``_S#H^]?__X/$$(7`=3!J`XV#
M=*/__VH!4&6A`````"N##`$``/\PZ-;7__^#Q!"%P(G&#X7;````Z1T!``"+
M0`R^`0```(M`&(E%Y&6A`````"N##`$``#FSF`$``(U^_XL`?A-J`%?_=>10
MZ+'8__^#Q!"%P'42BX.8`0``2#GX=8N^`0```.M?BQ"+0@B)P8'A``0@`('Y
M``0``'0,)0!!(``]`$$``'4%BT(,ZQMJ`FH`4F6A`````"N##`$``/\PZ/K9
M__^#Q!!145"+@YP!``#_-+#HQMG__X/$$(7`=95&Z6/___]EH0`````K@PP!
M```YLY@!``"+``^."____U)&4O]UY%#HX];__X/$$.O54(V#=J/__U"+1@S_
M,&6A`````"N##`$``/\PZ-[6__^+1@R#Q!"+`/9`"D!T&5=74&6A`````"N#
M#`$``/\PZ#K8__^#Q!!J`XV#E*/__VH!4&6A`````"N##`$``/\PZ(G6__^#
MQ!"%P(G&=#V-@Y*A___H..K__X7`BTX,=!Q64/\Q9:$`````*X,,`0``_S#H
M9];__X/$$.L/BX.<`0``BQ"+`>AU[/__4HV#>Z/__VH!4&6A`````"N##`$`
M`/\PB<;HA-7__X/$#(V3D*/__U)0_S;H(M;__V6A`````"N##`$``(L`QD!E
M`(V#B:'__^BXZ?__@\00A<")@Y0!``!U)H/L#/^SG`$``.A`]___@\00A<")
M@Y0!``!U"X/L#(V#EJ/__^LSB[.4`0``4%!HP`$``%;H[]3__XU0`8/$$(/Z
M`78;@_@1=!905HN#G`$``/\PC8.WH___4.B)U___C67T6UY?7<.0D)"0D)"0
MD(LT),-5B>53Z#S:__^!PS!C``!0_[,P`0``_W40_W4,_W4(Z"'5__^+7?S)
MPU6)Y5/H$]K__X'#!V,``%#HU];__P```%.#[`CH^]G__X'#[V(``(/$"%O#
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````#`````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O
M8R\E:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!
M4EE?4$%42`!P87(M`"UE`"TM`%-94U1%30`O=&UP`%5315(`55-%4DY!344`
M)3`R>``E<R5S)7,E<P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"5S.B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E
M=')Y('EO=7(@;W!E<F%T:6]N*0H`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S
M`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!414U01$E2`%1-4`!!
M4D=6`!@`<&5R;`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`U,`!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U
M:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H
M("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D
M<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R
M)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T
M;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P
M9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT
M("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D
M;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=
M.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE
M"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T
M;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO
M9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO
M=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@
M8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*
M7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?
M<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D
M92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M86=I8U]P;W,["FEF("@D
M<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E;'-I
M9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M86=I
M8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@)'-I
M>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2![
M"G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P*3L*<F5A9"A?1D@L("1B=68L("1C
M:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I*3L*:68@*"AM>2`D:2`]
M(')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S
M("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*
M;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]('1E
M;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@
M("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&
M24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U
M;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN
M86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<
M9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT
M*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX
M?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT
M(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN
M86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL
M96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\
M7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@
M)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@
M,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*
M?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF
M;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D:6YF;RT^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO
M<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D
M("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*
M9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L
M92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T
M7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T
M(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S
M=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S
M:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II
M("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R
M"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@
M/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q
M(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@
M>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@
M>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@
M)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG
M.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H
M)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA8
M6#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@
M9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]
M"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M
M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O
M+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=
M*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R
M(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B
M('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D
M;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E
M9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X[
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]
M"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]
M("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L
M(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K
M97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD
M=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T
M("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE
M*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@
M0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ
M9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]
M("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A
M8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O
M<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF
M("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M
M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=
M*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ
M36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S
M<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE
M>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<
M120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT
M96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F
M?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N
M)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`]
M(#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I
M.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N
M86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G
M3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*
M(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N
M="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O
M;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I
M=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U
M8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD
M(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG
M97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)&]U="D["F)I
M;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD
M8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA
M;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI
M.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P
M-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A
M<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI:
M:7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE
M;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!0
M05(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M(#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<
M)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES
M('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@
M>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA
M;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N
M86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I
M;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK
M*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@
M/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C
M=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE
M;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?
M;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&
M:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I
M(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#
M86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5
M<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=
M(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O
M=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM
M>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D
M8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE
M<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&
M:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@
M;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@
M>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN
M=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U
M:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M
M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@
M0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E
M(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII
M<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A
M<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)
M3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E
M=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E
M='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#
M.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY
M("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F
M:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@
M>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F
M:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD
M=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=3
M65-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S
M97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?
M0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@
M>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ
M."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U
M9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@
M979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F:"P@(CPB+"`D<')O9VYA;64I.PIB
M:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*
M96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP
M9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R
M(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H
M.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D[
M"GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G
M/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF
M:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I
M9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?
M5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P
M<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE
M('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@
M*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R
M;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P
M=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ
M("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@
M.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<
M+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN
M:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@
M>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#([
M"GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!2
M3T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ
M=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD
M7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI
M('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D
M14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D
M<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,
M14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*
M?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*
M<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]
M"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@
M9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R
M8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E
M;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR
M97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!
M4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P
M96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D
M:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE
M.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*
M?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$[
M"E]?14Y$7U\*`````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M`````'!E<FQX<VDN8P````$;`SL(`0``(````+R2__]0`0``?);__W0!``",
MEO__]`0``$R8__\D`0``7)G__X@!``#?IO__N`$``&^G___H`0``G:?__P@"
M```!J/__-`(``'VH__]@`@``WJG__Y`"``"IJO__P`(``$NL___P`@``BJS_
M_Q0#``#DK/__.`,``)2M__]H`P``K:W__XP#``!5K___O`,``&^O___<`P``
M%K#__P0$``!ML?__-`0``+>Q__]8!```X['__WP$``"*LO__N`0``/.R__\\
M!0``/[/__V`%``#IL___C`4``!*U__^\!0``2[O__^P%```KOO__'`8``#>^
M__\P!@``8+[__U0&```4``````````%Z4@`!?`@!&PP$!(@!!P@0````'```
M`""7__\L`````````!0``````````7I2``%\"`$;#`0$B`$``"`````<````
M9)'__\`#````#@A&#@Q*#PMT!'@`/QH[*C(D(A````!``````)7__P@`````
M````+````%0```#,E___@PT```!!#@B%`D0-!4J'`X8$@P4#<`W#0<9!QT'%
M#`0$````+````(0````?I?__D`````!!#@B%`D(-!4*'`X8$0X,%`H3#0<9!
MQT'%#`0$````'````+0```!_I?__+@````!!#@B%`D(-!6K%#`0$```H````
MU````(VE__]D`````$$."(4"0@T%088#3(,$`E'#0<9!Q0P$!````"@`````
M`0``Q:7__WP`````00X(A0)"#05!A@-#@P0"<L-!QD'%#`0$````+````"P!
M```5IO__80$```!!#@B%`D(-!4*'`X8$0X,%`U4!PT'&0<=!Q0P$!```+```
M`%P!``!&I___RP````!!#@B%`D(-!4*'`X8$28,%`KG#0<9!QT'%#`0$````
M+````(P!``#AI___H@$```!!#@B%`D(-!4*'`X8$0X,%`Y8!PT'&0<=!Q0P$
M!```(````+P!``!3J?__/P````!!#@B%`D(-!4&#`WK%PPP$!```(````.`!
M``!NJ?__6@````!!#@B%`D(-!4&#`P)5Q<,,!`0`+`````0"``"DJ?__L```
M``!!#@B%`D(-!4*'`X8$38,%`IK#0<9!QT'%#`0$````(````#0"```DJO__
M&0````!!#@B%`D(-!4&#`U/#0<4,!`0`+````%@"```9JO__J`$```!!#@B%
M`D(-!4.'`X8$@P4#G@'#0<9!QT'%#`0$````'````(@"``"1J___&@````!!
M#@B%`D(-!5;%#`0$```D````J`(``(NK__^G`````$$."(4"0@T%0H8#@P0"
MG\-!QD'%#`0$+````-`"```*K/__5P$```!!#@B%`D<-!4*'`X8$1(,%`T4!
MPT'&0<=!Q0P$!```(``````#```QK?__2@````!!#@B%`D(-!4&#`P)$PT'%
M#`0$(````"0#``!7K?__+`````!!#@B%`D(-!4&#`V?%PPP$!```.````$@#
M``!?K?__IP````!!#@B%`D(-!4.'`X8$@P4"D0K#0<9!QT'%#`0$10M$PT'&
M0<=!Q0P$!```.````(0#``#*K?__:0````!!#@B%`D(-!4.'`X8$@P4"4PK#
M0<9!QT'%#`0$10M$PT'&0<=!Q0P$!```1````,`#``"0D?__O@$```!$#`$`
M3!`%`G4`0A`'`G5\$`8"=7A#$`,"=71,#P-U<`8#E0'!#`$`0<-!QD''0<5#
M#`0$````(`````@$``"OK?__3`````!!#@B%`D(-!4&#`P)'Q<,,!`0`*```
M`"P$``#7K?__J@````!!#@B%`D(-!4>'`X8$@P4"G,-!QD''0<4,!`0L````
M6`0``%6N__\I`0```$$."(4"3`T%1X<#A@2#!0,1`<-!QD''0<4,!`0````L
M````B`0``$ZO__\Y!@```$$."(4"1PT%0H<#A@1)@P4#(@;#0<9!QT'%#`0$
M```L````N`0``%>U___@`@```$$."(4"0@T%0X<#A@2#!0/6`L-!QD''0<4,
M!`0````0````Z`0```>X__\,`````````"````#\!```_[?__RD`````00X(
MA0)"#05!@P-DQ<,,!`0``!@````@!0``!+C__Q4`````00X(A0)"#05!@P,`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````*,F``!?)@```0```#8#```!````00,```$```!+`P``#P```.4$
M```,`````"````T```#<2P``&0```+2M```;````!````!H```"XK0``'```
M``0````$````-`(``/7^_V^\!@``!0```#`.```&````$`@```H````#!0``
M"P```!`````5``````````,```#4K@```@```-@!```4````$0```!<```!H
M%0``$0```+@4```2````L````!,````(````&`````````#[__]O`0``"/[_
M_V_X$P``____;P(```#P__]O-!,``/K__V\+````````````````````````
M`````````````````````````````````+RM`````````````#8@``!&(```
M5B```&8@``!V(```AB```)8@``"F(```MB```,8@``#6(```YB```/8@```&
M(0``%B$``"8A```V(0``1B$``%8A``!F(0``=B$``(8A``"6(0``IB$``+8A
M``#&(0``UB$``.8A``#V(0``!B(``!8B```F(@``-B(``$8B``!6(@``9B(`
M`'8B``"&(@``EB(``*8B``"V(@``QB(``-8B``#F(@``]B(```8C```6(P``
M)B,``#8C``!&(P``5B,``&8C``!V(P``AB,``)8C``"F(P``MB,``,8C``#6
M(P````````````"O2```````````````````````````````````````````
M````````\",````````$L```]5```.Y0```W4@``"U$``#]2````````____
M_\Q2``!'0T,Z("A'3E4I(#$R+C,N,"`R,#(S,#4P."`H04]30R!/4RP@0V]R
M92D``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T
M92YG;G4N<')O<&5R='D`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y
M;@`N<F5L+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A
M`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````
M````````````````````````````````````````"P````$````"````M`$`
M`+0!```3```````````````!`````````!,````'`````@```,@!``#(`0``
M)```````````````!``````````F````!P````(```#L`0``[`$``"@`````
M``````````0`````````.0````<````"````%`(``!0"```@````````````
M```$`````````$L````%`````@```#0"```T`@``B`0```<`````````!```
M``0```!'````]O__;P(```"\!@``O`8``%0!```'``````````0````$````
M40````L````"````$`@``!`(```@!@``"`````$````$````$````%D````#
M`````@```#`.```P#@```P4``````````````0````````!A````____;P(`
M```T$P``-!,``,0````'``````````(````"````;@```/[__V\"````^!,`
M`/@3``#`````"`````(````$`````````'T````)`````@```+@4``"X%```
ML`````<`````````!`````@```"&````"0```$(```!H%0``:!4``-@!```'
M````&`````0````(````CP````$````&`````"`````@```@````````````
M```$`````````(H````!````!@```"`@```@(```P`,`````````````$```
M``0```"5`````0````8```#@(P``X",```@```````````````@````(````
MG@````$````&````\",``/`C``#I)P`````````````0`````````*0````!
M````!@```-Q+``#<2P``%```````````````!`````````"J`````0````(`
M````4````%```&(]``````````````0`````````L@````$````"````9(T`
M`&2-```,`0`````````````$`````````,`````!`````@```'".``!PC@``
M:`4`````````````!`````````#*````#@````,```"TK0``M)T```0`````
M``````````0````$````U@````\````#````N*T``+B=```$````````````
M```$````!````.(````&`````P```+RM``"\G0``&`$```@`````````!```
M``@```"9`````0````,```#4K@``U)X``"P!``````````````0````$````
MZP````$````#`````+````"@```H```````````````$`````````/$````(
M`````P```$"P```HH```0!``````````````(`````````#V`````0```#``
M````````**```"L```````````````$````!`````0````,`````````````
9`%.@``#_```````````````!````````````
